fs library
The fs_shim library.
File System abstraction layer for Dart. It provides a common API for file system access.
Classes
- Directory
- A reference to a directory on the file system.
- File
- A reference to a file on the file system.
- FileMode
- The mode in which a file is opened.
- FileSink
- A sink for writing to a file.
- FileStat
- Information about a file system object.
- FileSystem
- An abstract file system.
- FileSystemEntity
- A reference to an entity on the file system, such as a file or directory.
- FileSystemEntityParent
- Entity or FileSystem
- FileSystemEntityType
- The type of an entity on the file system, such as a file, directory, or link.
- FileSystemException
- An exception holding information about a file system error.
- FsShimSandboxedFileSystem
- A file system that is sandboxed to a specific directory.
- Link
- A reference to a link on the file system.
- OSError
- An error from the operating system.
- RandomAccessFile
- Random access to the data in a file.
Extensions
- FsShimDirectoryExtension on Directory
- Common extension helpers
- FsShimFileSystemExtension on FileSystem
- File system extension.