FileMode class

The mode in which a file is opened.

The FileMode is used by File.open to specify whether a file is opened for reading, writing, or appending.

Properties

hashCode int
The hash code for this object.
no setterinherited
mode int
The mode value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

append → const FileMode
The mode for opening a file for writing to the end of it.
read → const FileMode
The mode for opening a file for reading only.
write → const FileMode
The mode for opening a file for writing.