FileStat class abstract

Information about a file system object.

FileStat objects are returned from File.stat, Directory.stat, Link.stat, and FileSystemEntity.stat.

Implementers

Constructors

FileStat()

Properties

hashCode int
The hash code for this object.
no setterinherited
mode int
The mode of the file system object.
no setter
modified DateTime
The time of the last change to the data of the file system object.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int
The size of the file system object.
no setter
type FileSystemEntityType?
The type of the object (file, directory, or link).
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

modeNotSupported → const int
The mode is not supported on all file systems.