modeNotSupported constant
int
const modeNotSupported
The mode is not supported on all file systems.
Implementation
static const modeNotSupported = -1;
The mode is not supported on all file systems.
static const modeNotSupported = -1;