osError property
OSError?
get
osError
The underlying OS error.
Can be null if the exception is not raised due to an OS error.
Implementation
OSError? get osError;
The underlying OS error.
Can be null if the exception is not raised due to an OS error.
OSError? get osError;