path property
String?
get
path
The file system path on which the error occurred.
Can be null if the exception does not relate directly to a file system
path.
Implementation
String? get path;
The file system path on which the error occurred.
Can be null if the exception does not relate directly to a file system
path.
String? get path;