OSError class abstract

An error from the operating system.

Constructors

OSError()

Properties

errorCode int
The error code from the operating system.
no setter
hashCode int
The hash code for this object.
no setterinherited
message String
The error message from the operating system.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

noErrorCode → const int
Constant used to indicate that no OS error code is available.