errorCode property
int
get
errorCode
The error code from the operating system.
This is a platform-specific value.
If no error code is available, this is noErrorCode.
Implementation
int get errorCode;
The error code from the operating system.
This is a platform-specific value.
If no error code is available, this is noErrorCode.
int get errorCode;