fs_idb library

Classes

Directory
A reference to a directory on the file system.
File
A reference to a file on the file system.
FileMode
The mode in which a file is opened.
FileSink
A sink for writing to a file.
FileStat
Information about a file system object.
FileSystem
An abstract file system.
FileSystemEntity
A reference to an entity on the file system, such as a file or directory.
FileSystemEntityParent
Entity or FileSystem
FileSystemEntityType
The type of an entity on the file system, such as a file, directory, or link.
FileSystemException
An exception holding information about a file system error.
FileSystemIdbOptions
Idb file system options.
FsShimSandboxedFileSystem
A file system that is sandboxed to a specific directory.
A reference to a link on the file system.
OSError
An error from the operating system.
RandomAccessFile
Random access to the data in a file.

Extensions

FileSystemIdbExt on FileSystem
Web specific extesion
FileSystemIdbOptionsExt on FileSystemIdbOptions
Internal options helper.
FsShimDirectoryExtension on Directory
Common extension helpers
FsShimFileSystemExtension on FileSystem
File system extension.

Properties

fileSystemIdb FileSystem
The default browser file system on top of IndexedDB.
no setter

Functions

newFileSystemIdb(IdbFactory idbFactory, [String? dbPath]) FileSystem
Idb implementation (base for memory and browser)
newIdbFileSystem(IdbFactory idbFactory, [String? name]) FileSystem
Prefer newFileSystemIdb