FileSystemIdbOptions class

Idb file system options.

Available extensions

Constructors

FileSystemIdbOptions({int? pageSize})
Idb file system options.
const

Properties

debugName → String

Available on FileSystemIdbOptions, provided by the FileSystemIdbOptionsExt extension

Debug name
no setter
expectedPageSize → int

Available on FileSystemIdbOptions, provided by the FileSystemIdbOptionsExt extension

Expected page size when writing.
no setter
filePageSize → int

Available on FileSystemIdbOptions, provided by the FileSystemIdbOptionsExt extension

0 for none
no setter
hashCode → int
The hash code for this object.
no setterinherited
hasPageSize → bool

Available on FileSystemIdbOptions, provided by the FileSystemIdbOptionsExt extension

True if it as page size options
no setter
pageSize → int?
Default page size (null means no page).
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

noPage → const FileSystemIdbOptions
noPage means not optimized for random access and file streaming but optimized for full read and write.
pageDefault → const FileSystemIdbOptions
pageDefault means using 16Kb page.