FileStatModeMixin mixin

File stat mode mixin.

Implemented types

Properties

hashCode int
The hash code for this object.
no setterinherited
mode int
The mode of the file system object.
no setteroverride
modified DateTime
The time of the last change to the data of the file system object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int
The size of the file system object.
no setterinherited
type FileSystemEntityType?
The type of the object (file, directory, or link).
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited