FileSystemOpfsWebFileSystemEntityHandle class abstract
Wraps a JS FileSystemHandle, either a file
(FileSystemOpfsWebFileHandle) or a directory
(FileSystemOpfsWebDirectoryHandle) handle.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited