id property

String? id
final

By specifying an ID, the browser can remember different directories for different IDs. If the same ID is used for another picker, the picker opens in the same directory.

Implementation

final String? id;