mode property
modeRead (default) for read-only access or modeReadWrite for read and write access to the directory.
Implementation
final String? mode;
modeRead (default) for read-only access or modeReadWrite for read and write access to the directory.
final String? mode;