Glob class

Glob matching search. only support / * ** and ?

Convert everything to url internally

Constructors

Glob(String expression)
Global expression.

Properties

expression ↔ String
Global expression.
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
isDir → bool
True if the expression matches a dir (ends with '/').
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

matches(String name) → bool
true if the name matches the pattern
matchesParts(List<String> parts) → bool
True if it matches a path defined by parts.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

isGlobStar(String globPart) → bool
Glob star (**) matches everything and subdirs
matchPart(String? globPart, String? part) → bool
Check single part.