copy abstract method
Copies this file.
Returns a Future<File> that completes with a File instance for the
copied file.
If newPath identifies an existing file, that file is replaced. If
newPath identifies an existing directory, the operation fails and the
future completes with an exception.
Implementation
Future<File> copy(String newPath);