FileMode class
The mode in which a file is opened.
The FileMode is used by File.open to specify whether a file is opened for reading, writing, or appending.
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited