append constant
FileMode
const append
The mode for opening a file for writing to the end of it.
The file is created if it does not already exist.
Implementation
static const append = FileMode._internal(2);