FileSystem class abstract
An abstract file system.
- Implemented types
- Implementers
- Available extensions
Constructors
Properties
- currentDirectory → Directory
-
A Directory object pointing to the current working directory.
no setter
- debugName → String
-
Available on FileSystem, provided by the FileSystemDebugExt extension
debug nameno setter - hashCode → int
-
The hash code for this object.
no setterinherited
- hasIdbOptions → bool
-
Available on FileSystem, provided by the FileSystemIdbExt extension
Only true for idb file system.no setter - idbOptions → FileSystemIdbOptions
-
Available on FileSystem, provided by the FileSystemIdbExt extension
Idb specific options.no setter - name → String
-
The name of the file system.
no setter
- path → Context
-
The path context for this file system.
no setter
- pathContext → Context
-
Use path instead
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- supportsFileLink → bool
-
Whether the file system supports file links.
no setter
- supportsLink → bool
-
Whether the file system supports links.
no setter
- supportsRandomAccess → bool
-
Whether the file system supports random access.
no setter
Methods
-
absolutePath(
String path) → String -
Available on FileSystem, provided by the FsShimFileSystemExtension extension
Absolute path, normalized and with dot separators removed. Ifpathis already absolute, it is returned as is (after normalization and dot separator removal). Otherwise, it is joined with the path of currentDirectory to form an absolute path. -
childPath(
String path) → String -
Child path
inherited
-
directory(
String path) → Directory -
Creates a Directory object.
override
-
directoryWith(
{String? path}) → Directory -
Directory from an optional path, null meaning itself for Directory,
currentDirectory for FileSystem
inherited
-
file(
String path) → File -
Creates a File object.
override
-
isDirectory(
String path) → Future< bool> -
Checks if
type(path)returnsFileSystemEntityType.directory. -
isFile(
String path) → Future< bool> -
Checks if
type(path)returnsFileSystemEntityType.file. -
isLink(
String path) → Future< bool> -
Checks if
type(path, followLinks: false)returnsFileSystemEntityType.link. -
link(
String path) → Link -
Creates a Link object.
override
-
normalizePath(
String path) → String -
Available on FileSystem, provided by the FsShimFileSystemExtension extension
Normalize a path, removing redundant separators and up-level references. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pathEquals(
String path1, String path2) → bool -
Available on FileSystem, provided by the FsShimFileSystemExtension extension
Path equality based on absolute paths. -
pathHashCode(
String path) → int -
Available on FileSystem, provided by the FsShimFileSystemExtension extension
Path hash code based on absolute paths. -
recursiveUnsandbox(
{String? path}) → Directory -
Available on FileSystem, provided by the FsShimFileSystemExtension extension
Recursively unsandbox a file system, returning the root directory of the outermost sandbox. -
sandbox(
{String? path}) → FileSystem -
Available on FileSystem, provided by the FsShimFileSystemExtension extension
File system sandboxing Directory from an optional path, null meaning currentDirectory, -
toString(
) → String -
A string representation of this object.
inherited
-
type(
String path, {bool followLinks = true}) → Future< FileSystemEntityType> - Finds the type of file system object that a path points to.
-
unsandbox(
{String? path}) → Directory -
Available on FileSystem, provided by the FsShimFileSystemExtension extension
Unsandbox a file system, returning the root directory of the sandbox. return currentDirectory if not sandboxed. -
withIdbOptions(
{required FileSystemIdbOptions options}) → FileSystem -
Available on FileSystem, provided by the FileSystemIdbExt extension
Use a specific pageSize
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited