FileSystemException class abstract
An exception holding information about a file system error.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
A message describing the error.
no setter
- osError → OSError?
-
The underlying OS error.
no setter
- path → String?
-
The file system path on which the error occurred.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → int?
-
A status code for the error.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- statusAccessError → const int
- Generic access error.
- statusAlreadyExists → const int
- File already exists.
- statusInvalidArgument → const int
- Invalid argument.
- statusIsADirectory → const int
- Is a directory.
- statusNotADirectory → const int
- Not a directory.
- statusNotEmpty → const int
- Directory not empty.
- statusNotFound → const int
- File not found.