Link class abstract

A reference to a link on the file system.

Inheritance
Implementers

Constructors

Link(String path)
Creates a Link object.
factory

Properties

absolute → Link
Returns a Link instance whose path is the absolute path to this.
no setter
fs → FileSystem
The file system for this entity.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isAbsolute → bool
Returns a bool indicating whether this object's path is absolute.
no setterinherited
parent → Directory
The directory containing this.
no setterinherited
path → String
The path of the entity.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

create(String target, {bool recursive = false}) → Future<Link>
Creates a symbolic link.
delete({bool recursive = false}) → Future<FileSystemEntity>
Deletes this FileSystemEntity.
inherited
exists() → Future<bool>
Checks whether the file system entity with this path exists.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rename(String newPath) → Future<Link>
Renames this file system entity.
override
stat() → Future<FileStat>
Calls the operating system's stat() function on the path of this FileSystemEntity.
inherited
target() → Future<String>
Gets the target of the link.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited