FileSystemEntityMixin mixin
File system entity mixin.
- Implemented types
Properties
- fs → FileSystem
-
The file system for this entity.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setteroverride
- isAbsolute → bool
-
Returns a
boolindicating whether this object's path is absolute.no setteroverride - parent → Directory
-
The directory containing
this.no setteroverride - path → String
-
The path of the entity.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
delete(
{bool recursive = false}) → Future< FileSystemEntity> -
Deletes this FileSystemEntity.
override
-
exists(
) → Future< bool> -
Checks whether the file system entity with this path exists.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rename(
String newPath) → Future< FileSystemEntity> -
Renames this file system entity.
override
-
stat(
) → Future< FileStat> -
Calls the operating system's
stat()function on the path of this FileSystemEntity.override -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override