FileSystemOpfsWebFilePickerAcceptType class
A file type accepted by the file pickers (an entry of the types option of
window.showOpenFilePicker() and window.showSaveFilePicker()).
Constructors
Properties
-
accept
→ Map<
String, List< String> > -
MIME type to list of extensions, e.g.
{'text/plain': ['.txt']}.final - description → String?
-
Optional description of the category of files types allowed.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited