FileSystemOpfsWebPickerOptions class abstract
Common options for the File System Access API pickers
(window.showDirectoryPicker(), window.showOpenFilePicker() and
window.showSaveFilePicker()).
Constructors
- FileSystemOpfsWebPickerOptions({String? id, Object? startIn})
-
Common picker options.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String?
-
By specifying an ID, the browser can remember different directories for
different IDs. If the same ID is used for another picker, the picker
opens in the same directory.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startIn → Object?
-
A JS
FileSystemHandleor a well known directory (startInDesktop, startInDocuments, startInDownloads, startInMusic, startInPictures or startInVideos) to open the dialog in.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- startInDesktop → const String
- startIn well known directory: the user's desktop.
- startInDocuments → const String
- startIn well known directory: the user's documents.
- startInDownloads → const String
- startIn well known directory: the user's downloads.
- startInMusic → const String
- startIn well known directory: the user's music.
- startInPictures → const String
- startIn well known directory: the user's pictures.
- startInVideos → const String
- startIn well known directory: the user's videos.