FileSystemOpfsWebShowDirectoryPickerOptions class
Options for window.showDirectoryPicker() (File System Access API).
- Inheritance
-
- Object
- FileSystemOpfsWebPickerOptions
- FileSystemOpfsWebShowDirectoryPickerOptions
Constructors
- FileSystemOpfsWebShowDirectoryPickerOptions({String? id, String? mode, Object? startIn})
-
Options for
window.showDirectoryPicker().const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String?
-
By specifying an ID, the browser can remember different directories for
different IDs. If the same ID is used for another picker, the picker
opens in the same directory.
finalinherited
- mode → String?
-
modeRead (default) for read-only access or modeReadWrite for read
and write access to the directory.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startIn → Object?
-
A JS
FileSystemHandleor a well known directory (startInDesktop, startInDocuments, startInDownloads, startInMusic, startInPictures or startInVideos) to open the dialog in.finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited