FileSystemOpfsWebShowSaveFilePickerOptions class
Options for window.showSaveFilePicker() (File System Access API).
- Inheritance
-
- Object
- FileSystemOpfsWebPickerOptions
- FileSystemOpfsWebShowSaveFilePickerOptions
Constructors
-
FileSystemOpfsWebShowSaveFilePickerOptions({String? id, Object? startIn, String? suggestedName, bool? excludeAcceptAllOption, List<
FileSystemOpfsWebFilePickerAcceptType> ? types}) -
Options for
window.showSaveFilePicker().const
Properties
- excludeAcceptAllOption → bool?
-
Whether the picker should hide the option to not apply any of the
types filters (defaults to false).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String?
-
By specifying an ID, the browser can remember different directories for
different IDs. If the same ID is used for another picker, the picker
opens in the same directory.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startIn → Object?
-
A JS
FileSystemHandleor a well known directory (startInDesktop, startInDocuments, startInDownloads, startInMusic, startInPictures or startInVideos) to open the dialog in.finalinherited - suggestedName → String?
-
The suggested file name.
final
-
types
→ List<
FileSystemOpfsWebFilePickerAcceptType> ? -
The file types the picker allows to save as.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited