FileSystemEntityParent class abstract
Entity or FileSystem
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
childPath(
String path) → String - Child path
-
directory(
String path) → Directory - Child directory
-
directoryWith(
{String? path}) → Directory - Directory from an optional path, null meaning itself for Directory, currentDirectory for FileSystem
-
file(
String path) → File - Child file
-
link(
String path) → Link - Child link
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited